@@ -1,19 +1,22 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
 import json
 import logging
 import traceback
-import attr
-from typing import Tuple, Optional, Dict, List, TYPE_CHECKING
+from typing import TYPE_CHECKING, Dict, List, Optional, Tuple
 
+import attr
+from openlineage.client.facet import (
+    BaseFacet,
+    ExternalQueryRunFacet,
+    OutputStatisticsOutputDatasetFacet,
+)
 from openlineage.common.dataset import Dataset, Source
-from openlineage.common.models import DbTableSchema, DbColumn
+from openlineage.common.models import DbColumn, DbTableSchema
 from openlineage.common.schema import GITHUB_LOCATION
 from openlineage.common.sql import DbTableMeta
 from openlineage.common.utils import get_from_nullable_chain
-from openlineage.client.facet import BaseFacet, OutputStatisticsOutputDatasetFacet, \
-    ExternalQueryRunFacet
 
 _BIGQUERY_CONN_URL = 'bigquery'
 
