@@ -1,4 +1,4 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
 import collections
@@ -8,23 +8,26 @@ import logging
 import os
 import uuid
 from enum import Enum
-from typing import Dict, List, Optional, Tuple, TypeVar, Any
+from typing import Any, Dict, List, Optional, Tuple, TypeVar
 
 import attr
 import yaml
 from jinja2 import Environment, Undefined
-from openlineage.client.facet import (Assertion, BaseFacet,
-                                      DataQualityAssertionsDatasetFacet,
-                                      DataSourceDatasetFacet,
-                                      OutputStatisticsOutputDatasetFacet,
-                                      ParentRunFacet, SchemaDatasetFacet,
-                                      SchemaField, SqlJobFacet)
-from openlineage.client.run import (Dataset, Job, OutputDataset, Run, RunEvent,
-                                    RunState)
-
+from openlineage.client.facet import (
+    Assertion,
+    BaseFacet,
+    DataQualityAssertionsDatasetFacet,
+    DataSourceDatasetFacet,
+    OutputStatisticsOutputDatasetFacet,
+    ParentRunFacet,
+    SchemaDatasetFacet,
+    SchemaField,
+    SqlJobFacet,
+)
+from openlineage.client.run import Dataset, Job, OutputDataset, Run, RunEvent, RunState
+from openlineage.common.provider.snowflake import fix_account_name
 from openlineage.common.schema import GITHUB_LOCATION
-from openlineage.common.utils import (get_from_multiple_chains,
-                                      get_from_nullable_chain)
+from openlineage.common.utils import get_from_multiple_chains, get_from_nullable_chain
 
 
 class Adapter(Enum):
@@ -33,6 +36,7 @@ class Adapter(Enum):
     SNOWFLAKE = 'snowflake'
     REDSHIFT = 'redshift'
     SPARK = 'spark'
+    POSTGRES = 'postgres'
 
     @staticmethod
     def adapters() -> str:
@@ -215,7 +219,10 @@ class DbtArtifactProcessor:
         profile_dir = run_result['args']['profiles_dir']
 
         if not self.profile_name:
-            self.profile_name = self.project['profile']
+            if self.project.get('profile'):
+                self.profile_name = self.project.get('profile')
+            else:
+                raise KeyError(f'profile not found in {self.project}')
 
         profile = self.load_yaml_with_jinja(
             os.path.join(profile_dir, 'profiles.yml')
@@ -443,10 +450,10 @@ class DbtArtifactProcessor:
                 assertion_facet,
                 has_facets=False
             )
-
+            
             job_name = f"{node['database']}.{node['schema']}." \
                 f"{self.removeprefix(node['unique_id'], 'model.')}" \
-                + (".build.test" if self.command == 'build' else "")
+                + (".build.test" if self.command == 'build' else ".test")
 
             run_id = str(uuid.uuid4())
             events.add(self.to_openlineage_events(
@@ -683,11 +690,13 @@ class DbtArtifactProcessor:
     def extract_namespace(self, profile: Dict) -> str:
         """Extract namespace from profile's type"""
         if self.adapter_type == Adapter.SNOWFLAKE:
-            return f"snowflake://{profile['account']}"
+            return f"snowflake://{fix_account_name(profile['account'])}"
         elif self.adapter_type == Adapter.BIGQUERY:
             return "bigquery"
         elif self.adapter_type == Adapter.REDSHIFT:
             return f"redshift://{profile['host']}:{profile['port']}"
+        elif self.adapter_type == Adapter.POSTGRES:
+            return f"postgres://{profile['host']}:{profile['port']}"
         elif self.adapter_type == Adapter.SPARK:
             port = ""
 
