@@ -1,19 +1,22 @@
-# Copyright 2018-2022 contributors to the OpenLineage project
+# Copyright 2018-2023 contributors to the OpenLineage project
 # SPDX-License-Identifier: Apache-2.0
 
 import logging
-from typing import Optional, Union, List
+from typing import List, Optional, Union
 
+from openlineage_sql import (
+    ColumnLineage,  # noqa: F401
+    ColumnMeta,  # noqa: F401
+    DbTableMeta,  # noqa: F401
+    ExtractionError,  # noqa: F401
+    SqlMeta,  # noqa: F401
+    provider,  # noqa: F401
+)
+from openlineage_sql import parse as parse_sql  # noqa: F401  # noqa: F401
 
 log = logging.getLogger(__name__)
 
 
-try:
-    from openlineage_sql import parse as parse_sql, SqlMeta, DbTableMeta, provider  # noqa: F401
-except ImportError:
-    from openlineage.common.sql.parser import parse as parse_sql, SqlMeta, DbTableMeta, provider  # noqa: F401,E501
-
-
 def parse(
     sql: Union[List[str], str],
     dialect: Optional[str] = None,
